/*******************************************************************************
* File Name: .h
* Version 3.0
*
* Description:
*  This private file provides constants and parameter values for the
*  SCB Component.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PVT_UART_Console_H)
#define CY_SCB_PVT_UART_Console_H

#include "UART_Console.h"


/***************************************
*     Private Function Prototypes
***************************************/

/* APIs to service INTR_I2C_EC register */
#define UART_Console_SetI2CExtClkInterruptMode(interruptMask) UART_Console_WRITE_INTR_I2C_EC_MASK(interruptMask)
#define UART_Console_ClearI2CExtClkInterruptSource(interruptMask) UART_Console_CLEAR_INTR_I2C_EC(interruptMask)
#define UART_Console_GetI2CExtClkInterruptSource()                (UART_Console_INTR_I2C_EC_REG)
#define UART_Console_GetI2CExtClkInterruptMode()                  (UART_Console_INTR_I2C_EC_MASK_REG)
#define UART_Console_GetI2CExtClkInterruptSourceMasked()          (UART_Console_INTR_I2C_EC_MASKED_REG)

#if (!UART_Console_CY_SCBIP_V1)
    /* APIs to service INTR_SPI_EC register */
    #define UART_Console_SetSpiExtClkInterruptMode(interruptMask) \
                                                                UART_Console_WRITE_INTR_SPI_EC_MASK(interruptMask)
    #define UART_Console_ClearSpiExtClkInterruptSource(interruptMask) \
                                                                UART_Console_CLEAR_INTR_SPI_EC(interruptMask)
    #define UART_Console_GetExtSpiClkInterruptSource()                 (UART_Console_INTR_SPI_EC_REG)
    #define UART_Console_GetExtSpiClkInterruptMode()                   (UART_Console_INTR_SPI_EC_MASK_REG)
    #define UART_Console_GetExtSpiClkInterruptSourceMasked()           (UART_Console_INTR_SPI_EC_MASKED_REG)
#endif /* (!UART_Console_CY_SCBIP_V1) */

#if(UART_Console_SCB_MODE_UNCONFIG_CONST_CFG)
    extern void UART_Console_SetPins(uint32 mode, uint32 subMode, uint32 uartEnableMask);
#endif /* (UART_Console_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Vars with External Linkage
***************************************/

#if (UART_Console_SCB_IRQ_INTERNAL)
#if !defined (CY_REMOVE_UART_Console_CUSTOM_INTR_HANDLER)
    extern cyisraddress UART_Console_customIntrHandler;
#endif /* !defined (CY_REMOVE_UART_Console_CUSTOM_INTR_HANDLER) */
#endif /* (UART_Console_SCB_IRQ_INTERNAL) */

extern UART_Console_BACKUP_STRUCT UART_Console_backup;

#if(UART_Console_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common configuration variables */
    extern uint8 UART_Console_scbMode;
    extern uint8 UART_Console_scbEnableWake;
    extern uint8 UART_Console_scbEnableIntr;

    /* I2C configuration variables */
    extern uint8 UART_Console_mode;
    extern uint8 UART_Console_acceptAddr;

    /* SPI/UART configuration variables */
    extern volatile uint8 * UART_Console_rxBuffer;
    extern uint8   UART_Console_rxDataBits;
    extern uint32  UART_Console_rxBufferSize;

    extern volatile uint8 * UART_Console_txBuffer;
    extern uint8   UART_Console_txDataBits;
    extern uint32  UART_Console_txBufferSize;

    /* EZI2C configuration variables */
    extern uint8 UART_Console_numberOfAddr;
    extern uint8 UART_Console_subAddrSize;
#endif /* (UART_Console_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*        Conditional Macro
****************************************/

#if(UART_Console_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Defines run time operation mode */
    #define UART_Console_SCB_MODE_I2C_RUNTM_CFG     (UART_Console_SCB_MODE_I2C      == UART_Console_scbMode)
    #define UART_Console_SCB_MODE_SPI_RUNTM_CFG     (UART_Console_SCB_MODE_SPI      == UART_Console_scbMode)
    #define UART_Console_SCB_MODE_UART_RUNTM_CFG    (UART_Console_SCB_MODE_UART     == UART_Console_scbMode)
    #define UART_Console_SCB_MODE_EZI2C_RUNTM_CFG   (UART_Console_SCB_MODE_EZI2C    == UART_Console_scbMode)
    #define UART_Console_SCB_MODE_UNCONFIG_RUNTM_CFG \
                                                        (UART_Console_SCB_MODE_UNCONFIG == UART_Console_scbMode)

    /* Defines wakeup enable */
    #define UART_Console_SCB_WAKE_ENABLE_CHECK       (0u != UART_Console_scbEnableWake)
#endif /* (UART_Console_SCB_MODE_UNCONFIG_CONST_CFG) */

/* Defines maximum number of SCB pins */
#if (!UART_Console_CY_SCBIP_V1)
    #define UART_Console_SCB_PINS_NUMBER    (7u)
#else
    #define UART_Console_SCB_PINS_NUMBER    (2u)
#endif /* (!UART_Console_CY_SCBIP_V1) */

#endif /* (CY_SCB_PVT_UART_Console_H) */


/* [] END OF FILE */
