/*******************************************************************************
* File Name: UART_Console_SPI_UART_PVT.h
* Version 3.0
*
* Description:
*  This private file provides constants and parameter values for the
*  SCB Component in SPI and UART modes.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_SPI_UART_PVT_UART_Console_H)
#define CY_SCB_SPI_UART_PVT_UART_Console_H

#include "UART_Console_SPI_UART.h"


/***************************************
*     Internal Global Vars
***************************************/

#if (UART_Console_INTERNAL_RX_SW_BUFFER_CONST)
    extern volatile uint32  UART_Console_rxBufferHead;
    extern volatile uint32  UART_Console_rxBufferTail;
    extern volatile uint8   UART_Console_rxBufferOverflow;
#endif /* (UART_Console_INTERNAL_RX_SW_BUFFER_CONST) */

#if (UART_Console_INTERNAL_TX_SW_BUFFER_CONST)
    extern volatile uint32  UART_Console_txBufferHead;
    extern volatile uint32  UART_Console_txBufferTail;
#endif /* (UART_Console_INTERNAL_TX_SW_BUFFER_CONST) */

#if (UART_Console_INTERNAL_RX_SW_BUFFER)
    extern volatile uint8 UART_Console_rxBufferInternal[UART_Console_INTERNAL_RX_BUFFER_SIZE];
#endif /* (UART_Console_INTERNAL_RX_SW_BUFFER) */

#if (UART_Console_INTERNAL_TX_SW_BUFFER)
    extern volatile uint8 UART_Console_txBufferInternal[UART_Console_TX_BUFFER_SIZE];
#endif /* (UART_Console_INTERNAL_TX_SW_BUFFER) */


/***************************************
*     Private Function Prototypes
***************************************/

void UART_Console_SpiPostEnable(void);
void UART_Console_SpiStop(void);

#if (UART_Console_SCB_MODE_SPI_CONST_CFG)
    void UART_Console_SpiInit(void);
#endif /* (UART_Console_SCB_MODE_SPI_CONST_CFG) */

#if (UART_Console_SPI_WAKE_ENABLE_CONST)
    void UART_Console_SpiSaveConfig(void);
    void UART_Console_SpiRestoreConfig(void);
#endif /* (UART_Console_SPI_WAKE_ENABLE_CONST) */

void UART_Console_UartPostEnable(void);
void UART_Console_UartStop(void);

#if (UART_Console_SCB_MODE_UART_CONST_CFG)
    void UART_Console_UartInit(void);
#endif /* (UART_Console_SCB_MODE_UART_CONST_CFG) */

#if (UART_Console_UART_WAKE_ENABLE_CONST)
    void UART_Console_UartSaveConfig(void);
    void UART_Console_UartRestoreConfig(void);
#endif /* (UART_Console_UART_WAKE_ENABLE_CONST) */


/***************************************
*         UART API Constants
***************************************/

/* UART RX and TX position to be used in UART_Console_SetPins() */
#define UART_Console_UART_RX_PIN_ENABLE    (UART_Console_UART_RX)
#define UART_Console_UART_TX_PIN_ENABLE    (UART_Console_UART_TX)

/* UART RTS and CTS position to be used in  UART_Console_SetPins() */
#define UART_Console_UART_RTS_PIN_ENABLE    (0x10u)
#define UART_Console_UART_CTS_PIN_ENABLE    (0x20u)


/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

/* Interrupt processing */
#define UART_Console_SpiUartEnableIntRx(intSourceMask)  UART_Console_SetRxInterruptMode(intSourceMask)
#define UART_Console_SpiUartEnableIntTx(intSourceMask)  UART_Console_SetTxInterruptMode(intSourceMask)
uint32  UART_Console_SpiUartDisableIntRx(void);
uint32  UART_Console_SpiUartDisableIntTx(void);


#endif /* (CY_SCB_SPI_UART_PVT_UART_Console_H) */


/* [] END OF FILE */
