/*******************************************************************************
* File Name: Write_Switch.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Write_Switch.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        Write_Switch_PC =   (Write_Switch_PC & \
                                (uint32)(~(uint32)(Write_Switch_DRIVE_MODE_IND_MASK << (Write_Switch_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (Write_Switch_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: Write_Switch_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Write_Switch_Write(uint8 value) 
{
    uint8 drVal = (uint8)(Write_Switch_DR & (uint8)(~Write_Switch_MASK));
    drVal = (drVal | ((uint8)(value << Write_Switch_SHIFT) & Write_Switch_MASK));
    Write_Switch_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: Write_Switch_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Write_Switch_DM_STRONG     Strong Drive 
*  Write_Switch_DM_OD_HI      Open Drain, Drives High 
*  Write_Switch_DM_OD_LO      Open Drain, Drives Low 
*  Write_Switch_DM_RES_UP     Resistive Pull Up 
*  Write_Switch_DM_RES_DWN    Resistive Pull Down 
*  Write_Switch_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Write_Switch_DM_DIG_HIZ    High Impedance Digital 
*  Write_Switch_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Write_Switch_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(Write_Switch__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: Write_Switch_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Write_Switch_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Write_Switch_Read(void) 
{
    return (uint8)((Write_Switch_PS & Write_Switch_MASK) >> Write_Switch_SHIFT);
}


/*******************************************************************************
* Function Name: Write_Switch_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Write_Switch_ReadDataReg(void) 
{
    return (uint8)((Write_Switch_DR & Write_Switch_MASK) >> Write_Switch_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Write_Switch_INTSTAT) 

    /*******************************************************************************
    * Function Name: Write_Switch_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Write_Switch_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(Write_Switch_INTSTAT & Write_Switch_MASK);
		Write_Switch_INTSTAT = maskedStatus;
        return maskedStatus >> Write_Switch_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
